@@ -15,5 +15,5 @@ class Initialiser(Component):
             platforms.create_osso_context(values.OSSO_NAME, "1.0", False)
 
         Component.__init__(self)
-        theme.set_theme("kuro")
+        #theme.set_theme("kuro")
         
