@@ -2,8 +2,10 @@ def get_classes():
 
     from HeadphonesMonitor import HeadphonesMonitor
     from SoundVolumeMonitor import SoundVolumeMonitor
+    from PhoneMonitor import PhoneMonitor
     return [HeadphonesMonitor,
-            SoundVolumeMonitor]
+            SoundVolumeMonitor,
+            PhoneMonitor]
 
 
 
