@@ -23,6 +23,8 @@ class Widget(EventEmitter):
     
     SLIDE_LEFT = 0
     SLIDE_RIGHT = 1
+    SLIDE_UP = 2
+    SLIDE_DOWN = 3
     
     # static lock for animations
     __animation_lock = threading.Event()
@@ -945,3 +947,61 @@ class Widget(EventEmitter):
         screen = self.get_screen()
         self.animate(50, fx, [0, w])
 
+
+    def fx_slide_vertical(self, buf, x, y, w, h, direction):
+
+        def fx(params):
+            from_y, to_y = params
+            dy = (to_y - from_y) / 3
+
+            if (dy > 0):
+                if (direction == self.SLIDE_UP):
+                    screen.move_area(scr_x + x, scr_y + y + dy,
+                                     w, h - dy,
+                                     0, -dy)
+                    screen.copy_pixmap(buf,
+                                       x, y + from_y,
+                                       scr_x + x, scr_y + y + h - dy,
+                                       w, dy)
+                else:
+                    screen.move_area(scr_x + x, scr_y + y,
+                                     w, h - dy,
+                                     0, dy)
+                    screen.copy_pixmap(buf,
+                                       x, y + h - from_y - dy,
+                                       scr_x + x, scr_y + y,
+                                       w, dy)
+
+                params[0] = from_y + dy
+                params[1] = to_y
+                return True
+
+            else:
+                dy = to_y - from_y
+                if (direction == self.SLIDE_UP):
+                    screen.move_area(scr_x + x, scr_y + y + dy,
+                                     w, h - dy,
+                                     0, -dy)
+                    screen.copy_pixmap(buf,
+                                       x, y + from_y,
+                                       scr_x + x,
+                                       scr_y + y + h - dy,
+                                       w, dy)
+                else:
+                    screen.move_area(scr_x + x, scr_y + y,
+                                     w, h - dy,
+                                     0, dy)
+                    screen.copy_pixmap(buf,
+                                       x, y + h - from_y,
+                                       scr_y + x, scr_y + y,
+                                       w, dy)
+                
+                return False
+
+
+        if (not self.may_render()): return
+
+        scr_x, scr_y = self.get_screen_pos()
+        screen = self.get_screen()
+        self.animate(50, fx, [0, h])
+
